@@ -33,7 +33,7 @@
 #' if(is_keras_available()){
 #' 
 #'  mtcars$make <- unlist(lapply(strsplit(rownames(mtcars), " "), function(tokens) tokens[1]))
-#'  company <- kms(make ~ ., mtcars, Nepochs = 1)
+#'  company <- kms(make ~ ., mtcars, Nepochs = 1, verbose=0)
 #'  # out of sample accuracy
 #'  pCorrect <- mean(company$y_test == company$predictions)
 #'  pCorrect
@@ -44,12 +44,13 @@
 #'  company <- kms(make ~ ., mtcars,
 #'                 units = c(256, 128), 
 #'                 activation = c("relu", "relu", "softmax"),
-#'                 dropout = c(0.4, 0.3),
+#'                 dropout = 0.4,
 #'                 use_bias = TRUE,
 #'                 kernel_initializer = NULL,
 #'                 kernel_regularizer = "regularizer_l1",
 #'                 bias_regularizer = "regularizer_l1",
-#'                 activity_regularizer = "regularizer_l1"
+#'                 activity_regularizer = "regularizer_l1",
+#'                 Nepochs = 1, verbose=0
 #'                 )
 #'  # ?predict.kms_fit to see how to predict on newdata
 #' }else{
@@ -289,6 +290,8 @@ kms <- function(input_formula, data, keras_model_seq = NULL,
     
   }
   
+  layers <- NULL
+  
   if(is.null(keras_model_seq)){
     
     if(is.null(kernel_initializer))
